
# Slot: relation


interaction relationship type

URI: [biolink:pairwise_molecular_interaction_relation](https://w3id.org/biolink/vocab/pairwise_molecular_interaction_relation)


## Domain and Range

[PairwiseMolecularInteraction](PairwiseMolecularInteraction.md) &#8594;  <sub>1..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [pairwise gene to gene interaction➞relation](pairwise_gene_to_gene_interaction_relation.md)

## Children


## Used by

 * [PairwiseMolecularInteraction](PairwiseMolecularInteraction.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='RO:0002447', description='the subject molecular phosphorylates the object molecule') |

